@@ -9,12 +9,11 @@ has horse          => ( is => 'ro', to_hash => ',omit_if_empty', );
 has hen            => ( is => 'ro', to_hash => 1, );
 has secret_admirer => ( is => 'ro', );
 
-around TO_HASH => sub {
-    my ( $orig, $obj ) = @_;
-    my $hash = $obj->$orig;
-    $hash->{$_} = uc $hash->{$_} for grep defined $hash->{$_}, keys %$hash;
-    return $hash;
-};
+sub modify_hashr {
+    my ( $self, $hashr ) = @_;
+    $hashr->{$_} = uc $hashr->{$_}
+      for grep defined $hashr->{$_}, keys %$hashr;
+}
 
 1;
 
