@@ -14,11 +14,10 @@ has horse          => ( is => 'ro', to_json => ',omit_if_empty', );
 has hen            => ( is => 'ro', to_json => 1, );
 has secret_admirer => ( is => 'ro', );
 
-around TO_JSON => sub {
-    my ( $orig, $obj ) = @_;
-    my $hash = $obj->$orig;
-    $hash->{$_} = uc $hash->{$_} for grep defined $hash->{$_}, keys %$hash;
-    return $hash;
+sub modify_jsonr {
+    my ( $self, $jsonr ) = @_;
+    $jsonr->{$_} = uc $jsonr->{$_}
+      for grep defined $jsonr->{$_}, keys %$jsonr;
 };
 
 1;
